@@ -250,7 +250,8 @@ test_that("occu cloglog link function works",{
 
 test_that("occu predict works",{
   skip_on_cran()
-  skip_if(!require(raster), "raster package unavailable")
+  skip_if(!requireNamespace("raster", quietly=TRUE), 
+          "raster package unavailable")
   set.seed(55)
   R <- 20
   J <- 4
@@ -273,9 +274,9 @@ test_that("occu predict works",{
   E1.3 <- predict(fm1, type="state", newdata=nd1.1, appendData=TRUE)
   E1.4 <- predict(fm1, type="det", newdata=nd1.2)
 
-  r1 <- raster(matrix(rnorm(100), 10))
+  r1 <- raster::raster(matrix(rnorm(100), 10))
   expect_error(predict(fm1, type="state", newdata=r1))
-  s1 <- stack(r1)
+  s1 <- raster::stack(r1)
   expect_error(predict(fm1, type="state", newdata=s1))
   names(s1) <- c("x3")
   E1.5 <- predict(fm1, type="det", newdata=s1)
@@ -373,6 +374,13 @@ test_that("occu can handle random effects",{
   pb <- parboot(fm, nsim=1)
   expect_is(pb, "parboot")
 
+  # confint should only show fixed effects
+  ci <- confint(fm, type = 'state')
+  expect_equal(nrow(ci), 2)
+
+  ci <- confint(fm['state'])
+  expect_equal(nrow(ci), 2)
+
   # Check custom initial values
   expect_equal(fm@TMB$starts_order[1], "beta_det")
   fmi <- occu(~1~cov1 + (1|site_id), umf, starts=c(10,0,0,0))
@@ -406,3 +414,30 @@ test_that("occu can handle random effects",{
   test <- modSel(fl) # shouldn't warn
   #options(warn=0)
 })
+
+test_that("TMB engine gives correct det estimates when there are lots of NAs", {
+
+  skip_on_cran()
+  set.seed(123)
+  M <- 200
+  J <- 10
+  psi <- 0.5
+
+  z <- rbinom(M, 1, psi)
+
+  x <- matrix(rnorm(M*J), M, J)
+
+  p <- plogis(0 + 0.3*x)
+
+  y <- matrix(NA, M, J)
+  for (i in 1:M){
+    y[i,] <- rbinom(J, 1, p[i,]) * z[i]
+  }
+  y[sample(1:(M*J), (M*J/2), replace=FALSE)] <- NA
+
+  umf <- unmarkedFrameOccu(y=y, obsCovs=list(x=x))
+
+  fit <- occu(~x~1, umf)
+  fitT <- occu(~x~1, umf, engine="TMB")
+  expect_equal(coef(fit), coef(fitT), tol=1e-5)
+})
